/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/**
@fileoverview
Mozile Main Javascript.

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2005-05-15
HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	This file contains the global variables for the Mozile extension,
as well as some initiation functions.

*/


/********* Global Variables *********/

//Mozile Constants
var MOZILEC = new Object();			//Global object for constants.
MOZILEC.EXTENSION_DIR = "chrome://mozile/content/eDOM/";
MOZILEC.MES_DEFAULT = "chrome://mozile/content/mes/mes-XHTML.xml";
MOZILEC.TAGS_XHTML = "chrome://mozile/content/mes/tags-XHTML.css";
MOZILEC.NAMESPACE_XHTML = "http://www.w3.org/1999/xhtml";

var mozileTarget = "";         // the currently focussed window, if it has loaded Mozile.
var mozileSelection = "";      // the eDOM selection of the currently focussed window.
var mozilePrefs = "";          // Netscape preferences component

var mozile = new Object();     //Global object.
mozile.startup=true;
mozile.lastContextNode = null; //The last detected node.
mozile.version = "0.6.25.1";
mozile.keyMax = 20;            // the number of key presses before the state is saved to the Undo Stack.
mozile.undoMax = 100;          // the number of undo steps available.

var mozileToolbar = "";        // the Mozile toolbar
var mozileCommandMenu = "";

var mozileSourceSplitter = ""; // part of the Mozile source view box
var mozileSourceBox = "";      // the Mozile source view box
var mozileSourceTextbox = "";  // the Mozile source textbox
var mozileSourceMode = 1;      // source editing mode: 1=block, 0=page
var mozileSourceError = "";    // contains the source of the last parser error message
var mozileSourceSync = "";     // track the mozileSourceSync checkbox element
var mozileSourceNamespace = ""; // track the mozileSourceNamespace checkbox element

/********* Primary Functions *********/


// Mozile TB Start
// Initializes the mozilePrefs variable.

function mozileTBStart() {

			// the caret requires added privileges
	netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');
	mozilePrefs = Components.classes['@mozilla.org/preferences-service;1'].getService(Components.interfaces.nsIPrefService).getBranch(null);	
	
			// Initial configuration of preference values
	try {
		mozilePrefs.getBoolPref("mozile.acceleratorBool");
	} catch(e) {
		mozilePrefs.setBoolPref("mozile.acceleratorBool",false);
	}
	
	try {
		mozilePrefs.getBoolPref("mozile.autohideBool");
	} catch(e) {
		mozilePrefs.setBoolPref("mozile.autohideBool",false);
	}
	
	try {
		mozilePrefs.getBoolPref("mozile.caretAlwaysOnBool");
	} catch(e) {
		mozilePrefs.setBoolPref("mozile.caretAlwaysOnBool",false);
	}
	
	try {
		mozilePrefs.getBoolPref("mozile.onBool");
	} catch(e) {
		mozilePrefs.setBoolPref("mozile.onBool",true);
	}
	
	try {
		mozilePrefs.getBoolPref("mozile.promptOnUnloadBool");
	} catch(e) {
		mozilePrefs.setBoolPref("mozile.promptOnUnloadBool",true);
	}
	
	try {
		mozilePrefs.getIntPref("mozile.debugLevelInt");
	} catch(e) {
		mozilePrefs.setIntPref("mozile.debugLevelInt",0);
	}
	
		// set User Save preferences
	try {
		mozilePrefs.getCharPref("mozile.saveContentString");
	} catch(e) {
		mozilePrefs.setCharPref("mozile.saveContentString","page");
	}
	
	try {
		mozilePrefs.getCharPref("mozile.saveMethodString");
	} catch(e) {
		mozilePrefs.setCharPref("mozile.saveMethodString","display");
	}
	
	try {
		mozilePrefs.getCharPref("mozile.saveHttpPathString");
	} catch(e) {
		mozilePrefs.setCharPref("mozile.saveHttpPathString","");
	}
	
}

/* Code to execute on startup ... */
	mozileTBStart();
	document.addEventListener("load", mozileStartup, true);

// Initialise toolbar variables.
// Note: can't have onload handler for overlay file.
function mozileStartup() {
	mozileToolbar = document.getElementById("mozile-toolbar");
	mozileCommandMenu = document.getElementById("mozile-command-menu");
	mozileArrowbox = document.getElementById('mozile-arrowbox');
	mozile.menuKey = document.getElementById("mozile-menu").getAttribute("accesskey").toLowerCase();
	mozile.commandMenuKey = document.getElementById("mozile-command-menu").getAttribute("accesskey").toLowerCase();
	document.removeEventListener("load", mozileStartup, true);
	if ( mozilePrefs.getBoolPref("mozile.onBool") ) {
		mozileSwitchOn();
	} else {
		mozileSwitchOff();
	}
	mozile.startup=false;
}

